/**
 * @file
 * JavaScript behaviors for 'Hotkeys for Save' module.
 *
 * If hotkeys Ctrl+S (Win) or Cmd+S (Mac) are pressed, we are trying to find
 * submit button whose 'id' attribute is equal to the value from the specified
 * list.
 * And if such button was found we click on it.
 * The list includes the possible values of 'id' attribute that 'Save' buttons
 * can have.
 *
 * If on the page exist two buttons: 'Save' and 'Save and continue' then we
 * click on the button with 'continue' action.
 * For example, if exist two buttons: 'Save content type' and 'Save and add
 * fields', then we click on the 'Save and add fields' button.
 * Or if exist two buttons: 'Save & exit' and 'Continue & edit', then we clicked
 * on the 'Continue & edit' button.
 *
 * Also we prevent to opening browser's 'Save As' dialog.
 */

(($, Drupal) => {
  Drupal.behaviors.hotkeysForSave = {
    attach: (context) => {
      // The flag for preventing repeated submit when the key is pressed and held.
      let clickAllowed = true;

      $(document, context).keyup((e) => {
        if (e.keyCode === 83) {
          clickAllowed = true;
        }
      });

      $(document, context).keydown((e) => {
        if (e.keyCode === 83 && (navigator.platform.match('Mac') ? e.metaKey : e.ctrlKey)) {
          // Prevent to opening browser's 'Save As' dialog.
          e.preventDefault();
          // First we try to find 'Save and continue' buttons.
          let selector = [
            '#edit-save-continue',
            '#edit-next',
            '#edit-continue',
          ];
          let submitButton = document.querySelector(selector.join());
          // If 'Save and continue' buttons wasn't found then we find 'Save' buttons.
          if (submitButton === null) {
            selector = [
              '#edit-submit',
              '#edit-save',
              '#edit-actions-save',
              '#edit-return',
              '#edit-actions-submit',
            ];
            submitButton = document.querySelector(selector.join());
          }
          if (submitButton !== null && clickAllowed) {
            submitButton.click();
            // Preventing repeated submit.
            clickAllowed = false;
          }
        }
      });
    },
  };
})(jQuery, Drupal);
